<?php

namespace Moblyze\AssetMaintenance\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moblyze\AssetMaintenance\Http\Requests\AssetMaintenanceRequest;
use Moblyze\AssetMaintenance\Interfaces\AssetMaintenanceRepositoryInterface;
use Moblyze\AssetMaintenance\Models\AssetMaintenance;
use Moblyze\AssetMaintenance\Forms\AssetMaintenance as Form;

/**
 * APIController  class for asset_maintenance.
 */
class AssetMaintenanceAPIController extends BaseController
{

    /**
     * Initialize asset_maintenance resource controller.
     *
     * @param type AssetMaintenanceRepositoryInterface $asset_maintenance
     *
     * @return null
     */
    public function __construct(AssetMaintenanceRepositoryInterface $asset_maintenance)
    {
        parent::__construct();
        $this->repository = $asset_maintenance;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\AssetMaintenance\Repositories\Criteria\AssetMaintenanceResourceCriteria::class);
    }

    /**
     * Display a list of asset_maintenance.
     *
     * @return Response
     */
    public function index(AssetMaintenanceRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moblyze\AssetMaintenance\Repositories\Presenter\AssetMaintenancePresenter::class)
            ->paginate();
    }

    /**
     * Display asset_maintenance.
     *
     * @param Request $request
     * @param Model   $asset_maintenance
     *
     * @return Response
     */
    public function show(AssetMaintenanceRequest $request, AssetMaintenance $asset_maintenance)
    {
        return $asset_maintenance->setPresenter(\Moblyze\AssetMaintenance\Repositories\Presenter\AssetMaintenanceListPresenter::class);
        ;
    }

    /**
     * Create new asset_maintenance.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AssetMaintenanceRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('asset_maintenance::asset_maintenance.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('asset_maintenance/asset_maintenance/' . $asset_maintenance->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('asset_maintenance/asset_maintenance');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the asset_maintenance.
     *
     * @param Request $request
     * @param Model   $asset_maintenance
     *
     * @return Response
     */
    public function update(AssetMaintenanceRequest $request, AssetMaintenance $asset_maintenance)
    {
        try {
            $data = $request->all();

            $asset_maintenance->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('asset_maintenance::asset_maintenance.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('asset_maintenance/asset_maintenance/' . $asset_maintenance->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('asset_maintenance/asset_maintenance/' . $asset_maintenance->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the asset_maintenance.
     *
     * @param Model   $asset_maintenance
     *
     * @return Response
     */
    public function destroy(AssetMaintenanceRequest $request, AssetMaintenance $asset_maintenance)
    {
        try {
            $asset_maintenance->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('asset_maintenance::asset_maintenance.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('asset_maintenance/asset_maintenance/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('asset_maintenance/asset_maintenance/' . $asset_maintenance->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
