<?php

namespace Moblyze\AssetMaintenance\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\AssetMaintenance\Models\AssetMaintenance;

class AssetMaintenancePolicy
{

    /**
     * Determine if the given user can view the asset_maintenance.
     *
     * @param UserPolicy $user
     * @param AssetMaintenance $asset_maintenance
     *
     * @return bool
     */
    public function view(UserPolicy $user, AssetMaintenance $asset_maintenance)
    {
        if ($user->canDo('asset_maintenance.asset_maintenance.view') && $user->isAdmin()) {
            return true;
        }

        return $asset_maintenance->user_id == user_id() && $asset_maintenance->user_type == user_type();
    }

    /**
     * Determine if the given user can create a asset_maintenance.
     *
     * @param UserPolicy $user
     * @param AssetMaintenance $asset_maintenance
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('asset_maintenance.asset_maintenance.create');
    }

    /**
     * Determine if the given user can update the given asset_maintenance.
     *
     * @param UserPolicy $user
     * @param AssetMaintenance $asset_maintenance
     *
     * @return bool
     */
    public function update(UserPolicy $user, AssetMaintenance $asset_maintenance)
    {
        if ($user->canDo('asset_maintenance.asset_maintenance.edit') && $user->isAdmin()) {
            return true;
        }

        return $asset_maintenance->user_id == user_id() && $asset_maintenance->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given asset_maintenance.
     *
     * @param UserPolicy $user
     * @param AssetMaintenance $asset_maintenance
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, AssetMaintenance $asset_maintenance)
    {
        return $asset_maintenance->user_id == user_id() && $asset_maintenance->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given asset_maintenance.
     *
     * @param UserPolicy $user
     * @param AssetMaintenance $asset_maintenance
     *
     * @return bool
     */
    public function verify(UserPolicy $user, AssetMaintenance $asset_maintenance)
    {
        if ($user->canDo('asset_maintenance.asset_maintenance.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given asset_maintenance.
     *
     * @param UserPolicy $user
     * @param AssetMaintenance $asset_maintenance
     *
     * @return bool
     */
    public function approve(UserPolicy $user, AssetMaintenance $asset_maintenance)
    {
        if ($user->canDo('asset_maintenance.asset_maintenance.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
