<?php

namespace Moblyze\AssetMaintenance\Providers;

use Illuminate\Support\ServiceProvider;

class AssetMaintenanceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'asset_maintenance');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'asset_maintenance');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerAssetMaintenance();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerAssetMaintenance()
    {
        $this->app->bind('asset_maintenance', function($app) {
            return new AssetMaintenance($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('AssetMaintenance', 'Lavalite\AssetMaintenance\Facades\AssetMaintenance');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('moblyze.asset_maintenance', function ($app) {
            return $this->app->make('Moblyze\AssetMaintenance\AssetMaintenance');
        });

                // Bind AssetMaintenance to repository
        $this->app->bind(
            'Moblyze\AssetMaintenance\Interfaces\AssetMaintenanceRepositoryInterface',
            \Moblyze\AssetMaintenance\Repositories\Eloquent\AssetMaintenanceRepository::class
        );

        $this->app->register(\Moblyze\AssetMaintenance\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Moblyze\AssetMaintenance\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and asset_maintenance's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'moblyze.asset_maintenance'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeAssetMaintenance::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['moblyze.asset_maintenance'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('moblyze/asset_maintenance.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/asset_maintenance')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/asset_maintenance')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
